@@ -19,7 +19,7 @@
  * along with "Otags reloaded". If not, see
  * <http://www.gnu.org/licenses/>.
  * 
- * $Id: emacs.ml,v 1.11 2012-01-26 13:16:19 tews Exp $
+ * $Id: emacs.ml,v 1.12 2012-05-18 19:12:11 tews Exp $
  * 
  * write emacs tags files
  * 
@@ -95,13 +95,7 @@ let write_tag es loc tag =
    *)
   if es.file <> Loc.file_name loc 
   then 
-    (try
-       make_current_buffer es (Loc.file_name loc)
-     with
-       | Sys_error sys_msg ->
-	 let msg = "Original source not available: " ^ sys_msg in
-	 raise(Otags_parsing_error(loc, msg))
-    );
+    make_current_buffer es (Loc.file_name loc);
   Buffer.add_string es.current_buf 
     (emacs_tag_line
        (Misc.cut_out (get_channel loc) (Loc.start_bol loc) (Loc.stop_off loc))
