@@ -19,7 +19,7 @@
  * along with "Otags reloaded". If not, see
  * <http://www.gnu.org/licenses/>.
  * 
- * $Id: parser_factory.mli,v 1.5 2012-01-14 21:31:39 tews Exp $
+ * $Id: parser_factory.mli,v 1.6 2012-05-21 09:29:29 tews Exp $
  * 
  * build new camlp4 parsers
  * 
@@ -38,4 +38,4 @@ type parser_functions = {
 }
 
 
-val update_syntax : unit -> parser_functions
+val update_syntax : string list -> parser_functions
