@@ -19,7 +19,7 @@
  * along with "Otags reloaded". If not, see
  * <http://www.gnu.org/licenses/>.
  * 
- * $Id: source_channel.ml,v 1.1 2012-01-23 14:27:30 tews Exp $
+ * $Id: source_channel.ml,v 1.3 2012-05-22 06:16:46 tews Exp $
  * 
  * hold the in_channel of the source file
  * 
@@ -39,22 +39,33 @@ let reset () =
   then close_in !current_in_channel;
   current_file_name := ""
 
-let open_file file_name loc =
+let open_file ?(primary_file = false) file_name loc =
   reset ();
   current_in_channel := 
     (try
        open_in file_name
      with
        | Sys_error sys_msg -> 
-	 let msg = "Original source not available: " ^ sys_msg in
+	 let msg = 
+	   if primary_file
+	   then "Cannot open " ^ sys_msg
+	   else "Original source not available: " ^ sys_msg 
+	 in
 	 raise(Otags_parsing_error(loc, msg))
     );
   current_file_name := file_name
 
 
-let get_channel loc =
+let get_channel ?primary_file loc =
   if Loc.file_name loc <> !current_file_name
-  then open_file (Loc.file_name loc) loc;
+  then open_file ?primary_file (Loc.file_name loc) loc;
   !current_in_channel
     
 
+
+let full_string_of_loc loc =
+  Printf.sprintf "[%s: sl %d(%d) so %d el %d(%d) eo %d%s]"
+    (Loc.file_name loc)
+    (Loc.start_line loc) (Loc.start_bol loc) (Loc.start_off loc)
+    (Loc.stop_line loc) (Loc.stop_bol loc) (Loc.stop_off loc)
+    (if Loc.is_ghost loc then " GHOST" else " REAL")
