@@ -19,7 +19,7 @@
  * along with "Otags reloaded". If not, see
  * <http://www.gnu.org/licenses/>.
  * 
- * $Id: source_channel.mli,v 1.1 2012-01-23 14:27:30 tews Exp $
+ * $Id: source_channel.mli,v 1.3 2012-05-22 06:16:46 tews Exp $
  * 
  * hold the in_channel of the source file
  * 
@@ -30,6 +30,7 @@ open Types
 
 val reset : unit -> unit
 
-val get_channel : loc_t -> in_channel
+val get_channel : ?primary_file:bool -> loc_t -> in_channel
     
 
+val full_string_of_loc : Camlp4.PreCast.Loc.t -> string
