@@ -179,6 +179,11 @@ end = struct
   let a84 = 5
 end
 
+module type A85 = sig end
+
+module A86 = (val (module struct end : A85) : A85)
+
+
 (*** Local Variables: ***)
 (*** compile-command: "make -C .. testtrue" ***)
 (*** End: ***)
